package com.fs.provider.service;

import java.time.LocalDate;
import java.time.LocalTime;
import java.util.List;
import com.fs.provider.domain.ServiceGenConfig;
import com.fs.provider.vo.ServiceGenConfigAuditInfoVO;
import com.fs.provider.vo.ServiceGenConfigAuditReqVO;

/**
 * 任务生成配置Service接口
 * 
 * @author fs
 * @date 2026-01-27
 */
public interface IServiceGenConfigService 
{
    /**
     * 查询任务生成配置
     * 
     * @param id 任务生成配置主键
     * @return 任务生成配置
     */
    public ServiceGenConfig selectServiceGenConfigById(Long id);

    /**
     * 查询任务生成配置列表
     * 
     * @param serviceGenConfig 任务生成配置
     * @return 任务生成配置集合
     */
    public List<ServiceGenConfig> selectServiceGenConfigList(ServiceGenConfig serviceGenConfig);

    /**
     * 新增任务生成配置
     * 
     * @param serviceGenConfig 任务生成配置
     * @return 结果
     */
    public int insertServiceGenConfig(ServiceGenConfig serviceGenConfig);

    /**
     * 修改任务生成配置
     * 
     * @param serviceGenConfig 任务生成配置
     * @return 结果
     */
    public int updateServiceGenConfig(ServiceGenConfig serviceGenConfig);

    /**
     * 批量删除任务生成配置
     * 
     * @param ids 需要删除的任务生成配置主键集合
     * @return 结果
     */
    public int deleteServiceGenConfigByIds(Long[] ids);

    /**
     * 删除任务生成配置信息
     * 
     * @param id 任务生成配置主键
     * @return 结果
     */
    public int deleteServiceGenConfigById(Long id);

    int audit(ServiceGenConfigAuditReqVO serviceGenConfigAuditReqVO);

    int companyAudit(ServiceGenConfigAuditReqVO serviceGenConfigAuditReqVO);


    ServiceGenConfigAuditInfoVO getAuditInfoById(Long id);

    List<ServiceGenConfig> selectDueConfigs(LocalTime startTime, LocalTime endTime, LocalDate today);

    int companyInsertServiceGenConfig(ServiceGenConfig serviceGenConfig);


}
